==> camel-core-2.7.0-sources.jar: org/apache/camel/util/ExpressionComparator.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.util;

import java.util.Comparator;

import org.apache.camel.Exchange;
import org.apache.camel.Expression;

/**
 * An implementation of {@link Comparator} which takes an {@link Expression} which is evaluated
 * on each exchange to compare
 *  
 * @version 
 */
public class ExpressionComparator implements Comparator<Exchange> {
    private final Expression expression;

    public ExpressionComparator(Expression expression) {
        this.expression = expression;
    }

    public int compare(Exchange e1, Exchange e2) {
        Object o1 = expression.evaluate(e1, Object.class);
        Object o2 = expression.evaluate(e2, Object.class);
        return ObjectHelper.compare(o1, o2);
    }
}

==> camel-core-2.15-20150307.023702-161-sources.jar: org/apache/camel/util/ExpressionComparator.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.util;

import java.util.Comparator;

import org.apache.camel.Exchange;
import org.apache.camel.Expression;

/**
 * An implementation of {@link Comparator} that takes an {@link Expression} which is evaluated
 * on each exchange to be compared
 *  
 * @version 
 */
public class ExpressionComparator implements Comparator<Exchange> {
    private final Expression expression;

    public ExpressionComparator(Expression expression) {
        this.expression = expression;
    }

    public int compare(Exchange e1, Exchange e2) {
        Object o1 = expression.evaluate(e1, Object.class);
        Object o2 = expression.evaluate(e2, Object.class);
        return ObjectHelper.compare(o1, o2);
    }
}
